==> apache-bigtop-manager-1.0.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/en_US/common.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export default {
  prev: 'Previous',
  next: 'Next',
  done: 'Done',
  save: 'Save',
  exit: 'Exit',
  action: 'Action',
  operation: 'Operation',
  status: 'Status',
  healthy: 'Healthy',
  unhealthy: 'Unhealthy',
  unknown: 'Unknown',
  failed: 'Failed',
  success: 'Normal',
  edit: 'Edit',
  rename: 'Rename',
  delete: 'Delete',
  remove: 'Remove {0}',
  bulk_remove: 'Bulk Remove',
  batch_operation: 'Batch Operation',
  disable: 'Disable',
  enable: 'Enable',
  submit: 'Submit',
  retry: 'Retry',
  cancel: 'Cancel',
  confirm: 'Confirm',
  exit_confirm: 'Are you sure you want to exit?',
  install: 'Install',
  installing: 'Installing...',
  finish: 'Finish',
  more: 'More',
  view_all: 'View All',
  select_tips: 'Please select',
  name: 'Name',
  version: 'Version',
  desc: 'Description',
  os: 'OS',
  arch: 'Arch',
  base_url: 'Address',
  cluster: 'Cluster',
  host: 'Host',
  service: 'Service',
  stack: 'Stack',
  component: 'Component',
  componentname: 'Name',
  quick_link: 'Quick Link',
  no_link: 'No Link',
  stage: 'Stage',
  search: 'Search',
  reset: 'Reset',
  required: 'Required',
  not_required: 'Not Required',
  progress: 'Progress',
  status_change_success: 'Status changed successfully',
  test_success: 'Test successful!',
  created: 'Created!',
  update_success: 'Updated!',
  update_fail: 'Update fail',
  error_unknown: 'Unknown error',
  error_network: 'Network error',
  error_timeout: 'Request timeout',
  desc_404: 'Sorry, the page you visited does not exist.',
  back_home: 'Back Home',
  create_time: 'Create Time',
  update_time: 'Update Time',
  notification: 'Notification',
  copy: 'Copy',
  copied: 'Copied!',
  download: 'Download',
  copy_fail: 'Copy failed!',
  delete_success: 'Deleted!',
  delete_fail: 'Delete failed!',
  delete_confirm_title: 'Delete Confirm',
  delete_confirm_content: 'Delete will not be recoverable, are you sure you want to delete {0} ?',
  no_options: 'No options',
  loading_text_verifying: 'Verifying',
  enter_error: 'Please enter {0}',
  select_error: 'Please select {0}',
  add_error: 'Please add {0}',
  delete_msg: 'Are you sure you want to delete this?',
  delete_msgs: 'Are you sure you want to delete these?',
  restore_msg: 'Are you sure you want to restore this?',
  delete_empty: 'Please select the records you want to delete.',
  total: 'Total {0} items',
  note: 'Note: Changes to the source address will take effect for all clusters.',
  upload_file: 'Upload file',
  file_type_error: 'Only text files are allowed!',
  file_size_error: 'File size cannot exceed 10KB!',
  upload_success: 'File uploaded successfully!',
  upload_failed: 'File upload failed!',
  password_not_match: 'Passwords do not match.',
  overview: 'Overview',
  user: 'User',
  job: 'Job',
  start: 'Start {0}',
  restart: 'Restart {0}',
  stop: 'Stop {0}',
  add: 'Add {0}',
  success_msg: 'Added successfully',
  configs: 'Configs',
  more_operations: 'More Operations',
  ok: 'Ok',
  yes: 'Yes',
  no: 'No',
  all: 'All',
  disabled: 'Disabled',
  restore: 'Restore',
  selected: 'Selected',
  feature_not_supported: 'Feature not supported yet'
}

==> apache-bigtop-manager-1.1.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/en_US/common.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export default {
  prev: 'Previous',
  next: 'Next',
  done: 'Done',
  save: 'Save',
  exit: 'Exit',
  action: 'Action',
  operation: 'Operation',
  operate_success: 'Operation successful !',
  status: 'Status',
  healthy: 'Healthy',
  unhealthy: 'Unhealthy',
  unknown: 'Unknown',
  failed: 'Failed',
  success: 'Normal',
  edit: 'Edit',
  rename: 'Rename',
  delete: 'Delete {0}',
  remove: 'Remove {0}',
  bulk_remove: 'Bulk Remove',
  batch_operation: 'Batch Operation',
  disable: 'Disable',
  enable: 'Enable',
  submit: 'Submit',
  retry: 'Retry',
  cancel: 'Cancel',
  confirm: 'Confirm',
  exit_confirm: 'Are you sure you want to exit ?',
  install: 'Install',
  installing: 'Installing...',
  finish: 'Finish',
  more: 'More',
  view_all: 'View All',
  select_tips: 'Please select',
  name: 'Name',
  version: 'Version',
  desc: 'Description',
  os: 'OS',
  arch: 'Arch',
  cluster: 'Cluster',
  host: 'Host',
  service: 'Service',
  stack: 'Stack',
  component: 'Component',
  componentname: 'Name',
  quick_link: 'Quick Link',
  no_link: 'No Link',
  stage: 'Stage',
  search: 'Search',
  reset: 'Reset',
  required: 'Required',
  not_required: 'Not Required',
  progress: 'Progress',
  status_change_success: 'Status changed successful !',
  test_success: 'Test successful !',
  created: 'Created!',
  update_success: 'Updated!',
  update_fail: 'Update fail',
  error_unknown: 'Unknown error',
  error_network: 'Network error',
  error_timeout: 'Request timeout',
  desc_404: 'Sorry, the page you visited does not exist.',
  back_home: 'Back Home',
  create_time: 'Create Time',
  update_time: 'Update Time',
  notification: 'Notification',
  copy: 'Copy',
  copied: 'Copied !',
  download: 'Download',
  copy_fail: 'Copy failed !',
  delete_success: 'Deleted !',
  delete_fail: 'Delete failed !',
  delete_confirm_title: 'Delete Confirm',
  delete_confirm_content: 'Delete will not be recoverable, are you sure you want to delete {0} ?',
  no_options: 'No options',
  loading_text_verifying: 'Verifying',
  enter_error: 'Please enter {0}',
  select_error: 'Please select {0}',
  add_error: 'Please add {0}',
  delete_msg: 'Are you sure you want to delete this ?',
  delete_msgs: 'Are you sure you want to delete these ?',
  restore_msg: 'Are you sure you want to restore this ?',
  delete_empty: 'Please select the records you want to delete.',
  total: 'Total {0} items',
  upload_file: 'Upload file',
  file_type_error: 'Only text files are allowed !',
  file_size_error: 'File size cannot exceed 10KB !',
  upload_success: 'File uploaded successful !',
  upload_failed: 'File upload failed !',
  password_not_match: 'Passwords do not match.',
  overview: 'Overview',
  user: 'User',
  job: 'Job',
  start: 'Start {0}',
  restart: 'Restart {0}',
  stop: 'Stop {0}',
  add: 'Add {0}',
  success_msg: 'Added successful !',
  configs: 'Configs',
  more_operations: 'More Operations',
  ok: 'Ok',
  yes: 'Yes',
  no: 'No',
  all: 'All',
  disabled: 'Disabled',
  restore: 'Restore',
  selected: 'Selected',
  feature_not_supported: 'Feature not supported yet',
  installing_exit_confirm_content:
    'Installation is in progress, exiting the page will cause the installation to fail. Are you sure you want to exit ?',
  confirm_action: 'Are you sure you want to {action} {target} ?',
  confirm_comp_action: 'Are you sure you want to {action} selected components ?'
}
